@@ -10,34 +10,47 @@
 
 #include <glib.h>
 
-#define GROUPS_CALLBACK_NONE	(0)
-#define GROUPS_CALLBACK_INIT	(1 << 0)
-#define GROUPS_CALLBACK_REINIT	(1 << 1)
-
 struct smbconf_group {
-	unsigned short		cb_mode;
 	char			*name;
 	GHashTable		*kv;
 };
 
 struct smbconf_parser {
 	GHashTable		*groups;
-	struct smbconf_group	*current;
+	struct smbconf_group	*current, *global, *ipc;
 };
 
 extern struct smbconf_parser parser;
 
-int cp_parse_external_smbconf_group(char *name, char *opts);
-int cp_smbconfig_hash_create(const char *smbconf);
-void cp_smbconfig_destroy(void);
+static inline int cp_printable(unsigned char *p)
+{
+	/* eighth bit is ok due to utf-8 mb */
+	return *p >= 0x20 && *p != 0x7F;
+}
 
-int cp_parse_pwddb(const char *pwddb);
-int cp_parse_smbconf(const char *smbconf);
-int cp_parse_reload_smbconf(const char *smbconf);
+static inline int cp_smbconf_eol(char *p)
+{
+	return *p == 0x00 || *p == ';' || *p == '#';
+}
+
+static inline int cp_pwddb_eol(char *p)
+{
+	return *p == 0x00;
+}
+
+void cp_parse_external_smbconf_group(char *name, char **options);
+void cp_smbconf_parser_init(void);
+void cp_smbconf_parser_destroy(void);
+
+int cp_parse_smbconf(char *smbconf);
+int cp_parse_pwddb(char *pwddb);
 int cp_parse_subauth(void);
+int cp_parse_lock(void);
 
-char *cp_ltrim(char *v);
-int cp_key_cmp(char *k, char *v);
+unsigned long long cp_memparse(char *v);
+char *cp_ltrim(const char *v);
+char *cp_rtrim(const char *v, const char *p);
+int cp_key_cmp(const char *lk, const char *rk);
 char *cp_get_group_kv_string(char *v);
 int cp_get_group_kv_bool(char *v);
 unsigned long cp_get_group_kv_long_base(char *v, int base);
