@@ -29,6 +29,7 @@ struct ksmbd_heartbeat {
 #define KSMBD_GLOBAL_FLAG_SMB3_ENCRYPTION	(1 << 1)
 #define KSMBD_GLOBAL_FLAG_SMB3_MULTICHANNEL	(1 << 2)
 #define KSMBD_GLOBAL_FLAG_SMB3_ENCRYPTION_OFF	(1 << 3)
+#define KSMBD_GLOBAL_FLAG_DURABLE_HANDLES	(1 << 4)
 
 struct ksmbd_startup_request {
 	__u32	flags;
@@ -94,7 +95,8 @@ struct ksmbd_share_config_response {
 	__u16	force_uid;
 	__u16	force_gid;
 	__s8	share_name[KSMBD_REQ_MAX_SHARE_NAME];
-	__u32   reserved[112];		/* Reserved room */
+	__u32   reserved[111];		/* Reserved room */
+	__u32   payload_sz;
 	__u32	veto_list_sz;
 	__s8	____payload[];
 };
