@@ -39,27 +39,25 @@ static inline int test_user_flag(struct ksmbd_user *user, int bit)
 	return user->flags & bit;
 }
 
+int usm_remove_user(struct ksmbd_user *user);
 struct ksmbd_user *get_ksmbd_user(struct ksmbd_user *user);
 void put_ksmbd_user(struct ksmbd_user *user);
 
 struct ksmbd_user *usm_lookup_user(char *name);
 
-int usm_update_user_password(struct ksmbd_user *user, char *pass);
+void usm_update_user_password(struct ksmbd_user *user, char *pass);
 
+int usm_user_name(char *name, char *p);
 int usm_add_new_user(char *name, char *pwd);
-int usm_add_update_user_from_pwdentry(char *data);
 int usm_add_guest_account(char *name);
-int usm_add_subauth_global_conf(char *data);
 
 void usm_remove_all_users(void);
 
 void usm_destroy(void);
-int usm_init(void);
+void usm_init(void);
 
-typedef void (*walk_users)(gpointer key,
-			   gpointer value,
-			   gpointer user_data);
-void for_each_ksmbd_user(walk_users cb, gpointer user_data);
+typedef void (*user_cb)(struct ksmbd_user *user, void *data);
+void usm_iter_users(user_cb cb, void *data);
 
 struct ksmbd_login_request;
 struct ksmbd_login_response;
