@@ -65,39 +65,11 @@ static int generic_event(int type, void *payload, size_t sz)
 	return 0;
 }
 
-static int parse_reload_configs(const char *pwddb, const char *smbconf)
-{
-	int ret;
-
-	pr_debug("Reload config\n");
-
-	usm_remove_all_users();
-	ret = cp_parse_pwddb(pwddb);
-	if (ret == -ENOENT) {
-		pr_info("User database does not exist, "
-			"only guest sessions may work\n");
-	} else if (ret) {
-		pr_err("Failed to parse user database\n");
-		return ret;
-	}
-
-	shm_remove_all_shares();
-	ret = cp_parse_reload_smbconf(smbconf);
-	if (ret)
-		pr_err("Failed to parse configuration file\n");
-	return ret;
-}
-
 static int handle_generic_event(struct nl_cache_ops *unused,
 				struct genl_cmd *cmd,
 				struct genl_info *info,
 				void *arg)
 {
-	if (ksmbd_health_status & KSMBD_SHOULD_RELOAD_CONFIG) {
-		parse_reload_configs(global_conf.pwddb, global_conf.smbconf);
-		ksmbd_health_status &= ~KSMBD_SHOULD_RELOAD_CONFIG;
-	}
-
 	if (!info->attrs[cmd->c_id])
 		return NL_SKIP;
 
@@ -133,19 +105,17 @@ static int handle_unsupported_event(struct nl_cache_ops *unused,
 
 static int ifc_list_size(void)
 {
-	int len = 0;
-	int i;
+	char **pp = global_conf.interfaces;
+	int sz = 0;
 
-	for (i = 0; global_conf.interfaces[i] != NULL; i++) {
-		char *ifc = global_conf.interfaces[i];
+	for (; *pp; pp++) {
+		char *p = *pp;
 
-		ifc = cp_ltrim(ifc);
-		if (!ifc)
+		if (*p == 0x00)
 			continue;
-
-		len += strlen(ifc) + 1;
+		sz += strlen(p) + 1;
 	}
-	return len;
+	return sz;
 }
 
 static int ipc_ksmbd_starting_up(void)
@@ -207,21 +177,19 @@ static int ipc_ksmbd_starting_up(void)
 	}
 
 	if (ifc_list_sz) {
-		int i;
-		int sz = 0;
 		char *config_payload = KSMBD_STARTUP_CONFIG_INTERFACES(ev);
+		char **pp = global_conf.interfaces;
+		int sz = 0;
 
 		ev->ifc_list_sz = ifc_list_sz;
 
-		for (i = 0; global_conf.interfaces[i] != NULL; i++) {
-			char *ifc = global_conf.interfaces[i];
+		for (; *pp; pp++) {
+			char *p = *pp;
 
-			ifc = cp_ltrim(ifc);
-			if (!ifc)
+			if (*p == 0x00)
 				continue;
-
-			strcpy(config_payload + sz, ifc);
-			sz += strlen(ifc) + 1;
+			strcpy(config_payload + sz, p);
+			sz += strlen(p) + 1;
 		}
 
 		global_conf.bind_interfaces_only = 0;
@@ -233,21 +201,30 @@ static int ipc_ksmbd_starting_up(void)
 	return ret;
 }
 
-static int ipc_ksmbd_shutting_down(void)
-{
-	return 0;
-}
-
 int ipc_process_event(void)
 {
-	int ret = 0;
+	fd_set rfds;
+	int sk_fd, ret;
+
+	FD_ZERO(&rfds);
+
+	sk_fd = nl_socket_get_fd(sk);
+	FD_SET(sk_fd, &rfds);
+
+	if (select(sk_fd + 1, &rfds, NULL, NULL, NULL) < 0) {
+		if (errno != EINTR) {
+			ret = -errno;
+			pr_err("Can't wait on netlink socket: %m\n");
+			return ret;
+		}
+		ret = 0;
+		return ret;
+	}
 
 	ret = nl_recvmsgs_default(sk);
-	if (ret < 0) {
-		pr_err("nl_recv() returned error code %d: %s\n",
-		       ret, nl_geterror(ret));
-		return -KSMBD_STATUS_IPC_FATAL_ERROR;
-	}
+	if (ret < 0)
+		pr_err("nl_recv() failed, check dmesg, error: %s\n",
+		       nl_geterror(ret));
 	return ret;
 }
 
@@ -468,8 +445,9 @@ out_error:
 
 void ipc_destroy(void)
 {
-	if (ksmbd_health_status & KSMBD_HEALTH_RUNNING) {
-		ipc_ksmbd_shutting_down();
+	switch (genl_register_family(&ksmbd_family_ops)) {
+	case -NLE_EXIST:
+	case 0:
 		genl_unregister_family(&ksmbd_family_ops);
 	}
 
@@ -477,59 +455,49 @@ void ipc_destroy(void)
 	sk = NULL;
 }
 
-int ipc_init(void)
+void ipc_init(void)
 {
 	int ret;
 
+	if (sk)
+		return;
+
 	sk = nl_socket_alloc();
 	if (!sk) {
-		pr_err("Cannot allocate netlink socket\n");
-		goto out_error;
+		pr_err("Can't allocate netlink socket\n");
+		abort();
 	}
 
 	nl_socket_disable_seq_check(sk);
-	if (nl_socket_modify_cb(sk, NL_CB_VALID, NL_CB_CUSTOM,
-				nlink_msg_cb, NULL))
-		goto out_error;
+	nl_socket_modify_cb(sk, NL_CB_VALID, NL_CB_CUSTOM, nlink_msg_cb, NULL);
 
 	if (nl_connect(sk, NETLINK_GENERIC)) {
-		pr_err("Cannot connect to generic netlink\n");
-		goto out_error;
+		pr_err("Can't connect to generic netlink\n");
+		abort();
 	}
 
 	ret = nl_socket_set_buffer_size(sk, KSMBD_IPC_SO_RCVBUF_SIZE, 0);
 	if (ret) {
-		pr_err("Cannot set netlink socket buffer size: %s [%d]\n", nl_geterror(ret), ret);
-		goto out_error;
+		pr_err("Can't set netlink socket buffer size: %s\n",
+		       nl_geterror(ret));
+		abort();
 	}
 
 	if (genl_register_family(&ksmbd_family_ops)) {
-		pr_err("Cannot register netlink family\n");
-		goto out_error;
+		pr_err("Can't register netlink family\n");
+		abort();
 	}
 
-	do {
-		/*
-		 * Chances are we can start before ksmbd kernel module is up
-		 * and running. So just wait for the kksmbd to register the
-		 * netlink family and accept our connection.
-		 */
-		ret = genl_ops_resolve(sk, &ksmbd_family_ops);
-		if (ret) {
-			pr_err("Cannot resolve netlink family\n");
-			sleep(5);
-		}
-	} while (ret);
+	ret = genl_ops_resolve(sk, &ksmbd_family_ops);
+	if (ret) {
+		pr_err("Can't resolve netlink family\n");
+		abort();
+	}
 
 	if (ipc_ksmbd_starting_up()) {
-		pr_err("Unable to send startup event\n");
-		return -EINVAL;
+		pr_err("Can't send startup event\n");
+		abort();
 	}
 
 	ksmbd_health_status = KSMBD_HEALTH_RUNNING;
-	return 0;
-
-out_error:
-	ipc_destroy();
-	return -EINVAL;
 }
